"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@material-ui/core");
const contexts_1 = require("../../contexts");
const react_1 = __importStar(require("react"));
const react_alert_1 = require("react-alert");
const components_1 = require("../../components");
const OnboardingFlow_style_1 = require("../../flows/OnboardingFlow/OnboardingFlow.style");
const hooks_1 = require("../../hooks");
const theme_1 = require("../../theme");
const BalancesWidget_1 = __importDefault(require("../../widgets/BalancesWidget/BalancesWidget"));
const FundWidget_1 = __importDefault(require("../../widgets/FundWidget/FundWidget"));
const constants_1 = require("../../constants");
var EOnboardingScreens;
(function (EOnboardingScreens) {
    EOnboardingScreens[EOnboardingScreens["IDLE"] = 0] = "IDLE";
    EOnboardingScreens[EOnboardingScreens["MERCHANT_AUTHORIZATION"] = 1] = "MERCHANT_AUTHORIZATION";
    EOnboardingScreens[EOnboardingScreens["EMPTY_BALANCE"] = 2] = "EMPTY_BALANCE";
    EOnboardingScreens[EOnboardingScreens["FUND_WIDGET"] = 3] = "FUND_WIDGET";
    EOnboardingScreens[EOnboardingScreens["BALANCES"] = 4] = "BALANCES";
    EOnboardingScreens[EOnboardingScreens["ONBOARDING_SUCCESS"] = 5] = "ONBOARDING_SUCCESS";
})(EOnboardingScreens || (EOnboardingScreens = {}));
const OnboardingFlow = (props) => {
    const { gatewayUrl, finalSuccessContent = "You are good to go and purchase using your payment token", closeCallback = () => { }, gatewayName, } = props;
    const alert = react_alert_1.useAlert();
    const { balances } = hooks_1.useBalances();
    const { coreProxy } = contexts_1.useStoreContext();
    const { setLoading, closeModal } = contexts_1.useLayoutContext();
    const classes = OnboardingFlow_style_1.useStyles();
    const [currentSreen, setCurrentSreen] = react_1.useState(EOnboardingScreens.IDLE);
    react_1.useEffect(() => {
        setLoading(true);
        // First initialze the gateway
        coreProxy.getAuthorizedGateways().match((gatewaysMap) => {
            if (gatewaysMap.get(gatewayUrl)) {
                //check for balances
                coreProxy.getBalances().match((_balances) => {
                    var _a;
                    decideScreenWhenGatewayIsAlreadyAuthorized(!!((_a = _balances.assets) === null || _a === void 0 ? void 0 : _a.length));
                }, handleError);
            }
            else {
                setCurrentSreen(EOnboardingScreens.MERCHANT_AUTHORIZATION);
            }
            setLoading(false);
            // Then get the preferred payment token if there is any
            /* coreProxy.getPreferredPaymentToken().map((token) => {
              setPreferredPaymentTokenByAssetInfo(token);
            }); */
        }, handleError);
        coreProxy.onGatewayAuthorized.subscribe((_gatewayUrl) => {
            if (gatewayUrl === _gatewayUrl) {
                alert.success(`Gateway ${gatewayUrl} authorization succeeded!`);
                setLoading(false);
                coreProxy.getBalances().match((_balances) => {
                    var _a;
                    decideScreenWhenGatewayIsAlreadyAuthorized(!!((_a = _balances.assets) === null || _a === void 0 ? void 0 : _a.length));
                }, handleError);
            }
        });
        coreProxy.onAuthorizedGatewayActivationFailed.subscribe((_gatewayUrl) => {
            if (gatewayUrl === _gatewayUrl) {
                alert.error(`Gateway ${gatewayUrl} authorization failed!`);
                setLoading(false);
            }
        });
    }, []);
    // Watch funding success
    react_1.useEffect(() => {
        if ((balances === null || balances === void 0 ? void 0 : balances.length) && currentSreen === EOnboardingScreens.FUND_WIDGET) {
            setCurrentSreen(EOnboardingScreens.BALANCES);
        }
    }, [balances]);
    const decideScreenWhenGatewayIsAlreadyAuthorized = (hasBalances) => {
        if (hasBalances || (balances === null || balances === void 0 ? void 0 : balances.length)) {
            setCurrentSreen(EOnboardingScreens.BALANCES);
        }
        else {
            setCurrentSreen(EOnboardingScreens.EMPTY_BALANCE);
        }
    };
    const handleGatewayAuthorization = () => {
        setLoading(true);
        coreProxy.authorizeGateway(gatewayUrl).mapErr(handleError);
    };
    const goToFundWalletScreen = () => {
        setCurrentSreen(EOnboardingScreens.FUND_WIDGET);
    };
    const handleError = (err) => {
        setLoading(false);
        alert.error((err === null || err === void 0 ? void 0 : err.message) || "Something went wrong!");
    };
    const goToSuccessScreen = () => {
        setCurrentSreen(EOnboardingScreens.ONBOARDING_SUCCESS);
    };
    const renderFundWalletButton = (status) => {
        if (status === theme_1.EButtonStatus.secondary) {
            return (react_1.default.createElement(components_1.Button, { label: "Fund my wallet", onClick: goToFundWalletScreen, fullWidth: true, status: theme_1.EButtonStatus.secondary }));
        }
        return (react_1.default.createElement(components_1.Button, { label: "Fund my wallet", onClick: goToFundWalletScreen, fullWidth: true, bgColor: "linear-gradient(98deg, rgba(0,120,255,1) 0%, rgba(126,0,255,1) 100%)" }));
    };
    const onOkClick = () => {
        closeCallback();
        closeModal();
    };
    const renderScreen = () => {
        switch (currentSreen) {
            case EOnboardingScreens.IDLE:
                return react_1.default.createElement(react_1.default.Fragment, null, "Loading...");
            case EOnboardingScreens.MERCHANT_AUTHORIZATION:
                return (react_1.default.createElement(react_1.default.Fragment, null,
                    (balances === null || balances === void 0 ? void 0 : balances.length) ? (react_1.default.createElement(core_1.Box, null,
                        react_1.default.createElement(core_1.Box, { className: classes.balancesLabel }, "Your Balances"),
                        react_1.default.createElement(BalancesWidget_1.default, null))) : (react_1.default.createElement(react_1.default.Fragment, null,
                        react_1.default.createElement(core_1.Box, { className: classes.balancesEmptyLabel }, "You are getting closer!"),
                        react_1.default.createElement("img", { className: classes.authenticationImg, src: constants_1.AUTHENTICATION_IMAGE_URL }))),
                    react_1.default.createElement(components_1.Button, { label: `Approve ${gatewayName || "Hyperpay"}`, onClick: handleGatewayAuthorization, fullWidth: true, bgColor: "linear-gradient(98deg, rgba(0,120,255,1) 0%, rgba(126,0,255,1) 100%)" })));
            case EOnboardingScreens.EMPTY_BALANCE:
                return (react_1.default.createElement(react_1.default.Fragment, null,
                    react_1.default.createElement(core_1.Box, { className: classes.balancesEmptyLabel }, "You have successfully connected your wallet!"),
                    react_1.default.createElement("img", { className: classes.authenticationSuccessImg, src: constants_1.AUTHENTICATION_SUCCESS_IMAGE_URL }),
                    renderFundWalletButton()));
            case EOnboardingScreens.FUND_WIDGET:
                return react_1.default.createElement(FundWidget_1.default, null);
            case EOnboardingScreens.BALANCES:
                return (react_1.default.createElement(react_1.default.Fragment, null,
                    (balances === null || balances === void 0 ? void 0 : balances.length) && react_1.default.createElement(BalancesWidget_1.default, null),
                    react_1.default.createElement(core_1.Box, { className: classes.doneButtonWrapper },
                        react_1.default.createElement(components_1.Button, { label: "Done", onClick: goToSuccessScreen, fullWidth: true, bgColor: "linear-gradient(98deg, rgba(0,120,255,1) 0%, rgba(126,0,255,1) 100%)" })),
                    renderFundWalletButton(theme_1.EButtonStatus.secondary)));
            case EOnboardingScreens.ONBOARDING_SUCCESS:
                return (react_1.default.createElement(react_1.default.Fragment, null,
                    react_1.default.createElement(components_1.SucessContent, { label: "All good!", info: finalSuccessContent, onOkay: onOkClick }),
                    renderFundWalletButton(theme_1.EButtonStatus.secondary)));
            default:
                return react_1.default.createElement(core_1.Box, null, "Something went wrong!");
        }
    };
    return (react_1.default.createElement(core_1.Box, { className: classes.container },
        react_1.default.createElement(components_1.ModalHeader, null),
        renderScreen(),
        react_1.default.createElement(components_1.ModalFooter, null)));
};
exports.default = OnboardingFlow;
//# sourceMappingURL=OnboardingFlow.js.map