"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGateways = void 0;
const contexts_1 = require("../contexts");
const react_1 = require("react");
const react_alert_1 = require("react-alert");
var EActionTypes;
(function (EActionTypes) {
    EActionTypes["FETCHING"] = "FETCHING";
    EActionTypes["FETCHED"] = "FETCHED";
    EActionTypes["ERROR"] = "ERROR";
})(EActionTypes || (EActionTypes = {}));
function useGateways() {
    const { coreProxy } = contexts_1.useStoreContext();
    const alert = react_alert_1.useAlert();
    const initialState = {
        loading: true,
        error: null,
        gatewaysMap: new Map(),
        openGatewayIFrame,
        deauthorizeGateway,
        authorizeGateway,
    };
    const [state, dispatch] = react_1.useReducer((state, action) => {
        switch (action.type) {
            case EActionTypes.FETCHING:
                return Object.assign(Object.assign({}, state), { loading: true });
            case EActionTypes.FETCHED:
                return Object.assign(Object.assign({}, state), { loading: false, gatewaysMap: action.payload });
            case EActionTypes.ERROR:
                return Object.assign(Object.assign({}, state), { loading: false, error: action.payload });
            default:
                return state;
        }
    }, initialState);
    react_1.useEffect(() => {
        fetchData();
        coreProxy.onGatewayAuthorized.subscribe({
            next: (gatewayUrl) => {
                const gatewaysMap = state.gatewaysMap;
                gatewaysMap.set(gatewayUrl, true);
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: gatewaysMap,
                });
            },
        });
        coreProxy.onAuthorizedGatewayActivationFailed.subscribe({
            next: (gatewayUrl) => {
                const gatewaysMap = state.gatewaysMap;
                gatewaysMap.set(gatewayUrl, false);
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: gatewaysMap,
                });
            },
        });
    }, []);
    function fetchData() {
        return __awaiter(this, void 0, void 0, function* () {
            dispatch({ type: EActionTypes.FETCHING });
            coreProxy
                .getAuthorizedGatewaysConnectorsStatus()
                .map((gatewaysStatusMap) => {
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: gatewaysStatusMap,
                });
            })
                .mapErr((error) => {
                alert.error(error.message || "An error had happened while pulling gateway list");
                dispatch({ type: EActionTypes.ERROR, payload: error.message });
            });
        });
    }
    function openGatewayIFrame(gatewayUrl) {
        coreProxy.displayGatewayIFrame(gatewayUrl).mapErr((error) => {
            alert.error(error.message || "An error had happened while pulling gateway list");
            dispatch({ type: EActionTypes.ERROR, payload: error.message });
        });
    }
    function deauthorizeGateway(gatewayUrl) {
        dispatch({ type: EActionTypes.FETCHING });
        coreProxy
            .deauthorizeGateway(gatewayUrl)
            .map(() => {
            alert.success(`Gateway ${gatewayUrl} deauthorized successfully`);
            fetchData();
        })
            .mapErr((error) => {
            alert.error(error.message || "An error had happened while deauthorizing gateway");
            dispatch({ type: EActionTypes.ERROR, payload: error.message });
        });
    }
    function authorizeGateway(gatewayUrl) {
        dispatch({ type: EActionTypes.FETCHING });
        coreProxy
            .authorizeGateway(gatewayUrl)
            .map(() => {
            alert.success(`Gateway ${gatewayUrl} authorized successfully`);
            fetchData();
        })
            .mapErr((error) => {
            alert.error(error.message || "An error had happened while authorizing gateway");
            dispatch({ type: EActionTypes.ERROR, payload: error.message });
        });
    }
    return Object.assign({}, state);
}
exports.useGateways = useGateways;
//# sourceMappingURL=useGateways.js.map