"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const objects_1 = require("@hypernetlabs/objects");
const MainContainer_1 = __importDefault(require("../../containers/MainContainer"));
const contexts_1 = require("../../contexts");
const GatewaysWidget_1 = __importDefault(require("../../widgets/GatewaysWidget"));
const neverthrow_1 = require("neverthrow");
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const components_1 = require("../../components");
const constants_1 = require("../../constants");
const ConnectorAuthorizationFlow_1 = __importDefault(require("../../flows/ConnectorAuthorizationFlow"));
const OnboardingFlow_1 = __importDefault(require("../../flows/OnboardingFlow"));
const PrivateKeysFlow_1 = __importDefault(require("../../flows/PrivateKeysFlow"));
const utils_1 = require("../../utils");
const BalancesWidget_1 = __importDefault(require("../../widgets/BalancesWidget"));
const FundWidget_1 = __importDefault(require("../../widgets/FundWidget"));
const LinksWidget_1 = __importDefault(require("../../widgets/LinksWidget"));
const PaymentWidget_1 = require("../../widgets/PaymentWidget");
const PublicIdentifierWidget_1 = __importDefault(require("../../widgets/PublicIdentifierWidget"));
class HypernetWebUI {
    constructor(_coreInstance) {
        if (_coreInstance) {
            this.coreInstance = _coreInstance;
        }
        else if (window.hypernetCoreInstance) {
            this.coreInstance = window.hypernetCoreInstance;
        }
        else {
            throw new Error("core instance is required");
        }
        // This is to cache web ui instance in window so it may prevent from having multiple web ui instances
        window.hypernetWebUIInstance = HypernetWebUI.instance;
        this.viewUtils = new utils_1.ViewUtils();
        this.dateUtils = new utils_1.DateUtils();
    }
    _generateDomElement(selector) {
        if (document.getElementById(selector) == null) {
            this._removeExistedElement(selector);
            const element = document.createElement("div");
            element.setAttribute("id", selector);
            document.body.appendChild(element);
            document.getElementById(selector);
            return element;
        }
        return document.getElementById(selector);
    }
    _removeExistedElement(selector) {
        const element = document.getElementById(selector);
        if (element) {
            element.remove();
        }
    }
    _bootstrapComponent(component, withModal = false, closeCallback, modalStyle) {
        if (this.coreInstance == null) {
            throw new Error("core instance is required");
        }
        return (react_1.default.createElement(contexts_1.StoreProvider, { coreProxy: this.coreInstance, viewUtils: this.viewUtils, dateUtils: this.dateUtils },
            react_1.default.createElement(contexts_1.LayoutProvider, null,
                react_1.default.createElement(MainContainer_1.default, { withModal: withModal, closeCallback: closeCallback, modalStyle: modalStyle }, component))));
    }
    _getThrowableRender(renderReact) {
        const throwable = neverthrow_1.Result.fromThrowable(renderReact, (err) => {
            return new objects_1.RenderError("Error in fromThrowable", err);
        });
        return throwable();
    }
    renderPrivateKeysModal() {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(PrivateKeysFlow_1.default, null), true, undefined, {
                zIndex: 99999,
            }), this._generateDomElement(constants_1.PRIVATE_KEYS_FLOW_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderMetamaskWarningModal() {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(components_1.MetamaskWarning, null), true, undefined, {
                zIndex: 99999,
            }), this._generateDomElement(constants_1.METAMASK_WARNING_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderWarningAlertModal(errorMessage) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(components_1.WarningAlert, { errorMessage: errorMessage }), true, undefined, {
                zIndex: 99999,
            }), this._generateDomElement(constants_1.WARNING_ALERT_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderBalancesWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(BalancesWidget_1.default, Object.assign({}, config)), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.BALANCES_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderGatewaysWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(GatewaysWidget_1.default, Object.assign({}, config)), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.BALANCES_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderFundWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(FundWidget_1.default, Object.assign({}, config)), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.FUND_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderLinksWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(LinksWidget_1.default, Object.assign({}, config)), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.LINKS_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderPaymentWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(PaymentWidget_1.PaymentWidget, { counterPartyAccount: config === null || config === void 0 ? void 0 : config.counterPartyAccount, amount: config === null || config === void 0 ? void 0 : config.amount, expirationDate: config === null || config === void 0 ? void 0 : config.expirationDate, requiredStake: config === null || config === void 0 ? void 0 : config.requiredStake, paymentTokenAddress: config === null || config === void 0 ? void 0 : config.paymentTokenAddress, gatewayUrl: config === null || config === void 0 ? void 0 : config.gatewayUrl, paymentType: config === null || config === void 0 ? void 0 : config.paymentType }), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.PAYMENT_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderPublicIdentifierWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(PublicIdentifierWidget_1.default, Object.assign({}, config)), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.PUBLIC_IDENTIFIER_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderConnectorAuthorizationFlow(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(ConnectorAuthorizationFlow_1.default, { connectorUrl: config.connectorUrl, connectorName: config.connectorName, connectorLogoUrl: config.connectorLogoUrl }), config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.CONNECTOR_AUTHORIZATION_FLOW_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    startOnboardingFlow(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(OnboardingFlow_1.default, { gatewayUrl: config.gatewayUrl, gatewayName: config.gatewayName, gatewayLogoUrl: config.gatewayLogoUrl, finalSuccessContent: config.finalSuccessContent, closeCallback: config.closeCallback }), config.showInModal, config.closeCallback), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.ONBOARDING_FLOW_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
}
exports.default = HypernetWebUI;
window.HypernetWebUI = HypernetWebUI;
//# sourceMappingURL=HypernetWebUI.js.map